import os,sys,time
from struct import unpack
import gobject

script_path = os.path.abspath(os.path.dirname(sys.argv[0]))
focus_level=int(os.popen(script_path+"/v4l2-ctl -C focus_absolute|awk '{print $2}'").read())
focus_speed = 32
led_state = 0
ind_state = 0
zoom_stat = "off"
initial=1
led_command = script_path+"/v4l2-ctl -c torch_intensity="
ind_command = script_path+"/v4l2-ctl -c indicator_intensity="
focus_command = script_path+"/v4l2-ctl -c focus_absolute="
port = open("/dev/input/event1","rb")	
import dbus
from dbus.mainloop.glib import DBusGMainLoop
dbus_loop = DBusGMainLoop()
bus = dbus.SystemBus(mainloop=dbus_loop)
object  = bus.get_object("com.nokia.lfocus_comms.lfocus_service","/com/nokia/lfocus_comms/lfocus_service/object")
def signal_filter(lfocus_string):
		global led_state
		global ind_state
		if lfocus_string=="L1":		
			led_state=1
			print led_state
		if lfocus_string=="L0":		
			led_state=0
			print led_state
		if lfocus_string=="RL1":		
			ind_state=1
			print "r",ind_state
		if lfocus_string=="RL0":		
			ind_state=0
			print "r",ind_state
		if lfocus_string=="L1_R":		
			led_state=1
			print led_state
		if lfocus_string=="L0_R":		
			led_state=0
			print led_state
		if lfocus_string=="RL1_R":		
			ind_state=1
			print "r",ind_state
		if lfocus_string=="RL0_R":		
			ind_state=0
			print "r",ind_state
bus.add_signal_receiver(signal_filter,
			dbus_interface = 	"com.nokia.lfocus_comms.lfocus_service",
			signal_name =		"lfocus_signal")
def start_loop():
	global bus,initial,zoom_stat,ind_state,led_state,led_command,ind_command,focus_command,script_path,focus_level,port,focus_speed
	while 1:
		a,b,c = unpack("3B",port.read(3))	
		if a==1 :
			if c==30 :	
				focus_level+=focus_speed
				if focus_level > 1023 :
					focus_level = 1023
				os.system(focus_command+str(focus_level))	
			elif c==31 :
				focus_level-=focus_speed
				if focus_level < 0 :
					focus_level = 0
				os.system(focus_command+str(focus_level))	
			elif c==32 :
				focus_level=int(os.popen(script_path+"/v4l2-ctl -C focus_absolute|awk '{print $2}'").read())

			elif c==16 :
				if initial==1:
					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
					if int(stat)==0:
						object.lfocus_led1(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
						initial=0
						break
				elif led_state == 0 :
					object.lfocus_led1(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
					break
				break
			elif c==17 :
				if initial==1:
					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
					if int(stat)==1:
						object.lfocus_led0(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
						initial=0
						break
				elif led_state == 1 :
					object.lfocus_led0(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
					break
				break
			elif c==18 :
				if initial==1:
					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
					if int(stat)==0:
						object.lfocus_rled1(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
						initial=0
						break
				elif ind_state == 0 :
					object.lfocus_rled1(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
					break
				break
			elif c==19 :
				if initial==1:
					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
					if int(stat)==3:
						object.lfocus_rled0(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
						initial=0
						break
				elif ind_state == 1 :
					object.lfocus_rled0(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
					break
				break
			elif c==65 :	
				if zoom_stat == "off" :
					focus_level+=focus_speed
					if focus_level > 1023 :
						focus_level = 1023
					os.system(focus_command+str(focus_level))	
			elif c==66 :
				if zoom_stat == "off" :
					focus_level-=focus_speed
					if focus_level < 0 :
						focus_level = 0
					os.system(focus_command+str(focus_level))
	maintimer = gobject.timeout_add(10,start_loop2)
	
	if initial==0:
		initial = 2
		gobject.MainLoop().run()
		
def start_loop2():
	start_loop()
start_loop()
